############
Placeholders
############

..  class:: cms.models.placeholdermodel.Placeholder

    ``Placeholders`` can be filled with plugins, which store or generate content.


..  class:: cms.admin.placeholderadmin.PlaceholderAdminMixin